#include "nodes/base/base.hpp"
#include "nodes/stream/streamNode.hpp"

namespace Node
{

void StreamNode::work()
{
    cv::VideoCapture cap(stream_url_);
    if (!cap.isOpened())
    {
        std::cerr << "Error: cannot open camera" << std::endl;
        return;
    }

    while (running_)
    {
        cv::Mat frame;
        cap >> frame;
        frame_count_++;
        if (frame_count_ % skip_frame_ != 0)
        {
            printf("Skip frame %d\n", frame_count_);
            continue;
        }
        printf("%dx%d\n", frame.cols, frame.rows);
        if (frame.empty())
        {
            std::cerr << "Error: cannot read frame" << std::endl;
            break;
        }

        auto metaData = std::make_shared<meta::MetaData>();
        metaData->image = frame;

        for (auto& output_buffer : output_buffers_)
        {
            output_buffer.second->push(metaData);
            printf("Node %s push data to %s\n", name_.c_str(), output_buffer.first.c_str());
        }
    }
}


}   // namespace Node